==> james-project-3.7.6-source-release.zip: james-project/mailbox/cassandra/src/main/java/org/apache/james/mailbox/cassandra/table/CassandraMailboxTable.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.mailbox.cassandra.table;


public interface CassandraMailboxTable {
    String TABLE_NAME = "mailbox";
    String ID = "id";
    String MAILBOX_BASE = "mailboxbase";
    String UIDVALIDITY = "uidvalidity";
    String NAME = "name";
    String[] FIELDS = { ID, MAILBOX_BASE, UIDVALIDITY, NAME };

    interface MailboxBase {
        String USER = "user";
        String NAMESPACE = "namespace";
    }
}

==> james-project-3.9.0-source-release.zip: james-project/mailbox/cassandra/src/main/java/org/apache/james/mailbox/cassandra/table/CassandraMailboxTable.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.mailbox.cassandra.table;

import com.datastax.oss.driver.api.core.CqlIdentifier;

public interface CassandraMailboxTable {
    String TABLE_NAME = "mailbox";
    CqlIdentifier ID = CqlIdentifier.fromCql("id");
    CqlIdentifier MAILBOX_BASE = CqlIdentifier.fromCql("mailboxbase");
    CqlIdentifier UIDVALIDITY = CqlIdentifier.fromCql("uidvalidity");
    CqlIdentifier NAME = CqlIdentifier.fromCql("name");
    CqlIdentifier[] FIELDS = { ID, MAILBOX_BASE, UIDVALIDITY, NAME };

    interface MailboxBase {
        CqlIdentifier USER = CqlIdentifier.fromCql("user");
        CqlIdentifier NAMESPACE = CqlIdentifier.fromCql("namespace");
    }
}
